##  Updating Subscriptions in Bulk
Editing fact sheets in table view allows you to update subscriptions in bulk. You can change the subscription type and roles by moving users' emails from one column to another. This is helpful when you need to correct subscription types or roles for many users, such as changing users mistakenly subscribed as responsible to observers or when adjusting the governance policy, which might involve changing who is responsible or accountable for maintaining specific fact sheets.
Bulk updates are also possible by importing data through Excel files. To learn more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
